@@ -67,6 +67,23 @@ GVContactsTable::initModel ()
     }
 }//GVContactsTable::initModel
 
+QNetworkRequest
+GVContactsTable::createRequest(QString strUrl)
+{
+    QUrl url (strUrl);
+    QNetworkRequest request(url);
+    request.setHeader (QNetworkRequest::ContentTypeHeader,
+                       "application/x-www-form-urlencoded");
+    if (0 != strGoogleAuth.size ())
+    {
+        QByteArray byAuth = QString("GoogleLogin auth=%1")
+                                    .arg(strGoogleAuth).toAscii ();
+        request.setRawHeader ("Authorization", byAuth);
+    }
+
+    return request;
+}//GVContactsTable::createRequest
+
 QNetworkReply *
 GVContactsTable::postRequest (QString         strUrl,
                               QStringPairList arrPairs,
@@ -82,16 +99,7 @@ GVContactsTable::postRequest (QString         strUrl,
     }
     QString strParams = arrParams.join ("&");
 
-    QUrl url (strUrl);
-    QNetworkRequest request(url);
-    request.setHeader (QNetworkRequest::ContentTypeHeader,
-                       "application/x-www-form-urlencoded");
-    if (0 != strGoogleAuth.size ())
-    {
-        QByteArray byAuth = QString("GoogleLogin auth=%1")
-                                    .arg(strGoogleAuth).toAscii ();
-        request.setRawHeader ("Authorization", byAuth);
-    }
+    QNetworkRequest request = createRequest (strUrl);
     QByteArray byPostData = strParams.toAscii ();
 
     QObject::connect (&nwMgr   , SIGNAL (finished (QNetworkReply *)),
@@ -105,17 +113,7 @@ GVContactsTable::getRequest (QString         strUrl,
                              QObject        *receiver,
                              const char     *method)
 {
-    QUrl url (strUrl);
-    QNetworkRequest request(url);
-    request.setHeader (QNetworkRequest::ContentTypeHeader,
-                       "application/x-www-form-urlencoded");
-    if (0 != strGoogleAuth.size ())
-    {
-        QByteArray byAuth = QString("GoogleLogin auth=%1")
-                                    .arg(strGoogleAuth).toAscii ();
-        request.setRawHeader ("Authorization", byAuth);
-    }
-
+    QNetworkRequest request = createRequest (strUrl);
     QObject::connect (&nwMgr   , SIGNAL (finished (QNetworkReply *)),
                        receiver, method);
     QNetworkReply *reply = nwMgr.get (request);
@@ -312,12 +310,15 @@ GVContactsTable::onGotContacts (QNetworkReply *reply)
         dbMain.setLastContactUpdate (currDT);
 
         QThread *workerThread = new QThread(this);
-        ContactsParserObject *pObj = new ContactsParserObject(byData);
+        ContactsParserObject *pObj =
+        new ContactsParserObject(byData, strGoogleAuth);
         pObj->moveToThread (workerThread);
         QObject::connect (workerThread, SIGNAL(started()),
                           pObj        , SLOT  (doWork()));
         QObject::connect (pObj, SIGNAL(done(bool)),
                           this, SLOT  (onContactsParsed(bool)));
+        QObject::connect (pObj, SIGNAL(done(bool)),
+                          pObj, SLOT  (deleteLater ()));
         QObject::connect (pObj        , SIGNAL(done(bool)),
                           workerThread, SLOT  (quit()));
         QObject::connect (workerThread, SIGNAL(terminated()),
